"use client";

import Image from "next/image";


import { ContentLines } from "@/components/shared/content-lines";
import { Button } from "@/components/ui/button";
import { Card } from "@/components/ui/card";
import { ImageBaseUrl } from "@/configs/api";
import { Link } from "@/i18n/routing";
import { useProject } from "@/servers/data/use-project";
import { useLocale, useTranslations } from "next-intl";
import { usePathname } from "next/navigation";
import React from "react";


function RelatedProjectsClient() {

	const t = useTranslations();
	const pathname = usePathname();
	const { projects } = useProject(3);

	const filteredProjects = React.useMemo(() => {
		const projectName = pathname.split("/").pop();
		return projects?.filter((project: any) => project?.project_slug !== projectName) ?? [];

	}, [projects, pathname]);

	return (
		<section className="container mx-auto flex max-w-7xl flex-col py-16">
			{/* Header */}
			<div className="mb-6 text-center">
				<ContentLines
					title={t("Other Projects")}
					underlineColor="custom-primary-accent"
					centered
					textColor="text-custom-primary-accent"
				/>
				<h2 className="text-4xl font-semibold">
					{t("Bin Taleb Projects")}
				</h2>
			</div>

			{/* projects Grid */}

			{filteredProjects?.length > 0 ?
				<div className="flex items-center justify-center gap-4">
					{
						filteredProjects?.map((project: any, index: number) => (
							<ProjectCard key={index} project={project} />
						))
					}
				</div>
				:
				<div className="flex items-center justify-center">
					<p className="text-md font-thin text-gray-500">{t("No similar projects found")}</p>
				</div>

			}

		</section>
	);
}


const ProjectCard = ({ project }: { project: any }) => {
	const locale = useLocale();
	const t = useTranslations();

	return (
		<Card key={project?.id} className="flex-col overflow-hidden rounded-md border-none bg-white shadow-md w-96">
			<div className="relative h-[300px] w-full">
				<Image
					src={ImageBaseUrl + project?.thumbnail?.image_path}
					alt={project?.thumbnail?.name}
					fill
					className="object-cover"
				/>
			</div>
			<div className="flex flex-1 flex-col items-center gap-2 p-4">
				<h3 className="text-lg font-semibold">
					{locale === "ar" ? project?.title_ar : project?.title_en}
				</h3>
				<p className="text-sm text-gray-500">
					{locale === "ar" ? project?.description_ar : project?.description_en}
				</p>
			</div>
			<div className="flex flex-1 flex-col items-center gap-2 p-4">
				<Button variant="default" className="w-fit rounded-lg bg-custom-primary-accent text-white hover:bg-custom-primary-accent/90"
					asChild>
					<Link
						href={`/projects/${project?.id}` as any}
					>
						{t("Details")}
					</Link>
				</Button>

			</div>
		</Card>
	);
};

export default RelatedProjectsClient;
